@@ -1,13 +1,21 @@
 #' Add a textual citation 
 #'
-#' Parameters listed here are the same for parenthetical citation, \code{\link{citep}}.  
+#' Parameters listed here are the same for parenthetical 
+#'  citation, \code{\link{citep}}.  
 #' @param x a doi or list of dois, or a bibentry (or list of bibentries)
 #' @param cito Semantic reason for the citation. Only active if linked=TRUE
-#' @param tooltip Show a citation information on mouseover. Requires the tooltip javascript from http://twitter.github.com/bootstrap Pass logical TRUE/FALSE or set default behavior with \code{\link{cite_options}}
-#' @param linked link the inline citation text to the resource by doi (if available) or url? Pass logical TRUE/FALSE or set default behavior with \code{\link{cite_options}}
-#' @param numerical use citation instead of author-year format? (Not functional yet!) Pass logical TRUE/FALSE or set default behavior with \code{\link{cite_options}}
+#' @param tooltip Show a citation information on mouseover. Requires the
+#'  tooltip javascript from http://twitter.github.com/bootstrap Pass 
+#'  logical TRUE/FALSE or set default behavior with \code{\link{cite_options}}
+#' @param linked link the inline citation text to the resource by doi 
+#'  (if available) or url? Pass logical TRUE/FALSE or set default behavior 
+#'  with \code{\link{cite_options}}
+#' @param numerical use citation instead of author-year format? (Not 
+#'  functional yet!) Pass logical TRUE/FALSE or set default behavior 
+#'  with \code{\link{cite_options}}
 #' @param format_inline_fn function to format a single inline citation
 #' @param inline_format a function for formating the inline citation, defaults to authoryear_t (designed for internal use only)
+#' @param page optional page range added after citation
 #' @return a text inline citation
 #' @details Stores the full citation in a "works_cited" list,
 #' which can be printed with \code{\link{bibliography}}.
@@ -38,8 +46,7 @@ citet <- function(x, cito = NULL,
                   linked = get("linked", envir=knitcitations_options), 
                   numerical = get("numerical", envir=knitcitations_options), 
                   format_inline_fn = format_authoryear_t,  
-                  inline_format = authoryear_t){
-# FIXME 
+                  inline_format = authoryear_t, page = NULL){
   out <- cite(x, format_inline_fn = format_inline_fn)
   if(length(out) > 1) {
     output <- paste(sapply(out, citet, cito, tooltip, linked, format_inline_fn, inline_format), collapse="; ", sep="")
@@ -54,15 +61,32 @@ citet <- function(x, cito = NULL,
         link <- paste('href="', out$url, '"', sep='')
       output <- paste('<a ', link, citoproperty, '>', I(inline_format(out[[1]])), '</a>', sep='')
       if(tooltip){
-        bibinfo <- gsub('"', '', format(out)) # no quotes in text formatting please
-        bibinfo <- gsub('<URL:', '', bibinfo) # kill other stupid characters too
-        bibinfo <- gsub('>', '', bibinfo) 
-        output <- paste('<span class="showtooltip" title="', bibinfo, '">', output, '</span>', sep='')
+        bibinfo <- format(out, "html")
+        # Clean up silly default html formatting -- nope, just have to strip the html.  
+        bibinfo <- gsub('<p>', '', bibinfo) 
+#        bibinfo <- gsub('B>', 'strong>', bibinfo) 
+#        bibinfo <- gsub('EM>', 'em>', bibinfo) 
+         bibinfo <- gsub("&ldquo;", "'", bibinfo) # okay if data-html is on 
+         bibinfo <- gsub("&rdquo;", "'", bibinfo) # okay if data-html is on 
+         bibinfo <- gsub("&ndash;", "-", bibinfo)  # okay if data-html is on 
+         bibinfo <- gsub('<a .*</a>', '', bibinfo) 
+         bibinfo <- gsub('<B>', '', bibinfo) 
+         bibinfo <- gsub('<EM>', '', bibinfo) 
+         bibinfo <- gsub('</B>', '', bibinfo) 
+         bibinfo <- gsub('</EM>', '', bibinfo) 
+         bibinfo <- gsub('\\n', ' ', bibinfo) 
+         bibinfo <- gsub(', \\.', '.', bibinfo) 
+     output <- paste('<span class="showtooltip" title="', bibinfo, '">', output, '</span>', sep='')
       }
     } else { # not linked 
       output <- inline_format(out)
     }
-  }  
-  output
+  } 
+  if(!is.null(page)){
+    pgs <- ifelse(grepl("-", page), "pp.", "p.")
+    page <- paste(",", pgs, page)
+  }
+
+  paste(output, page)
 }
 
